import { Reporter } from "gatsby";
import { BaseContentBlock } from "notion-types";
interface NotionBlock extends BaseContentBlock {
    has_children?: boolean;
}
export interface NotionServiceOptions {
    reporter: Reporter;
    parallelLimit?: number;
    enableCaching?: boolean;
}
export declare class NotionService {
    private reporter;
    private parallelLimit;
    private enableCaching;
    private cache;
    private limiter;
    constructor(options: NotionServiceOptions);
    /**
     * GET 요청을 수행하는 함수 (재시도 로직 포함)
     */
    private fetchGetWithRetry;
    /**
     * POST 요청을 수행하는 함수 (재시도 로직 포함)
     */
    private fetchPostWithRetry;
    /**
     * 모든 블록 데이터를 가져오는 함수 (next_cursor 지원)
     */
    private fetchAllBlocks;
    /**
     * 데이터베이스 쿼리
     */
    queryDatabase(databaseId: string, body?: any): Promise<any>;
    /**
     * 페이지의 자식 블록 가져오기 (재귀적 처리)
     */
    getPageBlocks(pageId: string): Promise<NotionBlock[]>;
    /**
     * has_children이 true인 블록들의 자식을 재귀적으로 가져옴
     */
    private fetchChildBlocks;
    /**
     * 여러 페이지의 블록 병렬 처리
     */
    getMultiplePagesBlocks(pageIds: string[]): Promise<{
        [id: string]: NotionBlock[];
    }>;
    /**
     * 캐시 초기화
     */
    clearCache(): void;
    /**
     * 병렬 처리 제한 설정
     */
    setParallelLimit(limit: number): void;
}
export {};
