/**
 * This file provides TypeScript bindings to the Notion API processing.
 * Currently using the TypeScript implementation as the default.
 */
import { Reporter } from "gatsby";
/**
 * Notion Block type from the Notion API
 */
export type NotionBlock = any;
/**
 * Options for the RustNotionService
 */
export interface RustNotionServiceOptions {
    reporter: Reporter;
    notionApiKey: string;
    parallelLimit?: number;
    enableCaching?: boolean;
}
/**
 * A wrapper class that provides access to the TypeScript implementation
 * for parallel processing of Notion API requests.
 */
export declare class RustNotionService {
    private reporter;
    private notionApiKey;
    private parallelLimit;
    private enableCaching;
    private cache;
    constructor(options: RustNotionServiceOptions);
    /**
     * Get blocks for a single page, with recursive fetching of child blocks
     */
    getPageBlocks(pageId: string): Promise<NotionBlock[]>;
    /**
     * Get blocks for multiple pages in parallel
     */
    getMultiplePagesBlocks(pageIds: string[]): Promise<{
        [id: string]: NotionBlock[];
    }>;
    /**
     * Set the parallel processing limit
     */
    setParallelLimit(limit: number): void;
}
