"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.RustNotionService = void 0;
/**
 * A wrapper class that provides access to the TypeScript implementation
 * for parallel processing of Notion API requests.
 */
class RustNotionService {
    reporter;
    notionApiKey;
    parallelLimit;
    enableCaching;
    cache;
    constructor(options) {
        this.reporter = options.reporter;
        this.notionApiKey = options.notionApiKey;
        this.parallelLimit = options.parallelLimit || 5;
        this.enableCaching = options.enableCaching !== false;
        this.cache = new Map();
        this.reporter.info(`[NOTION] Initialized TypeScript-based parallel processing with limit: ${this.parallelLimit}`);
    }
    /**
     * Get blocks for a single page, with recursive fetching of child blocks
     */
    async getPageBlocks(pageId) {
        const cacheKey = `page-blocks-${pageId}`;
        if (this.enableCaching && this.cache.has(cacheKey)) {
            this.reporter.info(`[CACHE] Using cached page blocks for ${pageId}`);
            return this.cache.get(cacheKey);
        }
        const results = await this.getMultiplePagesBlocks([pageId]);
        const blocks = results[pageId] || [];
        if (this.enableCaching) {
            this.cache.set(cacheKey, blocks);
        }
        return blocks;
    }
    /**
     * Get blocks for multiple pages in parallel
     */
    async getMultiplePagesBlocks(pageIds) {
        this.reporter.info(`[NOTION] Fetching blocks for ${pageIds.length} pages in parallel (limit: ${this.parallelLimit})`);
        // Import the TypeScript implementation
        const { NotionService } = await Promise.resolve().then(() => __importStar(require("./api/service/notionService")));
        // Create a NotionService instance with the same configuration
        const tsService = new NotionService({
            reporter: this.reporter,
            parallelLimit: this.parallelLimit,
            enableCaching: this.enableCaching,
        });
        return tsService.getMultiplePagesBlocks(pageIds);
    }
    /**
     * Set the parallel processing limit
     */
    setParallelLimit(limit) {
        this.reporter.info(`[NOTION] Updated parallel request limit to ${limit}`);
        this.parallelLimit = limit;
    }
}
exports.RustNotionService = RustNotionService;
